@@ -2,6 +2,7 @@
 import argparse
 import sys
 import traceback
+import datetime
 from typing import List
 
 HELP_MSG = '''
@@ -19,6 +20,7 @@ The most commonly used commands are:
     data_update             run download_raw, update_basic, update_derived and update_view in turn
     check_fund_list         check fund list to get new funds and delisted funds
     dump_tables_and_dfs     dump all tables and dfs of fund dm to s3
+    update_stock_factor     update stock factor and factor return
 '''
 
 
@@ -38,14 +40,12 @@ class SurfingEntrance(object):
         getattr(self, args.command)()
 
     def _get_yesterday(self):
-        import datetime
         yesterday = datetime.datetime.today() - datetime.timedelta(days = 1)
         yesterday_str = datetime.datetime.strftime(yesterday, '%Y%m%d')
         print(f'yesterday: {yesterday_str}')
         return yesterday_str
 
     def datetime_test(self):
-        import datetime
         print(datetime.datetime.today())
 
     def init_raw(self):
@@ -169,13 +169,19 @@ class SurfingEntrance(object):
         wechat_bot = WechatBot()
         wechat_bot.send_data_update_status(yesterday, failed_tasks, updated_count)
 
+        print('start to check fund list')
         self.check_fund_list(yesterday, wechat_bot)
+        print('check fund list done')
+        print('start to dump tables and dfs')
         self.dump_tables_and_dfs(yesterday, wechat_bot)
+        print('dump tables and dfs done')
+        print('start to update stock factor')
+        self.update_stock_factor(yesterday, wechat_bot)
+        print('update stock factor done')
 
     def calc_fund_estimated_nav(self):
         # Use Jenkins to call this function every hour
         import time
-        import datetime
         from .util.config import SurfingConfigurator
         from .data.fund.raw.raw_data_helper import RawDataHelper
         from .data.fund.basic.fund_estimated_nav_processor import FundEstimatedNavProcessor
@@ -251,7 +257,6 @@ class SurfingEntrance(object):
     def calc_index_price(self):
         # Use Jenkins to call this function every hour
         import time
-        import datetime
         from .util.config import SurfingConfigurator
         from .data.fund.raw.raw_data_helper import RawDataHelper
         from .data.fund.raw.em_raw_data_downloader import EmRawDataDownloader
@@ -397,6 +402,46 @@ class SurfingEntrance(object):
             wechat_bot = WechatBot()
         wechat_bot.send_dump_to_s3_result(yesterday, failed_tables, failed_dfs)
 
+    def update_stock_factor(self, yesterday=None, wechat_bot=None):
+        import pandas as pd
+        from .stock.factor.api import StockFactorUpdater
+        from .data.manager import DataManager
+        from .data.api.basic import BasicDataApi
+
+        if yesterday is None:
+            yesterday = self._get_yesterday()
+
+        # 获取下一个交易日
+        trading_day_df = BasicDataApi().get_trading_day_list(start_date=yesterday)
+        if trading_day_df.shape[0] <= 1:
+            print(f'get trading days start with {yesterday} failed')
+            failed_factors: List[str] = ['get_trading_day for stock factor updating']
+        else:
+            next_trading_day = trading_day_df.iloc[1, :].datetime
+            print(f'got next trading day {next_trading_day}')
+            end_date_dt = pd.to_datetime(yesterday, infer_datetime_format=True).date()
+            next_trading_dt = pd.to_datetime(next_trading_day, infer_datetime_format=True).date()
+            if end_date_dt.weekday() < next_trading_dt.weekday() and next_trading_dt < end_date_dt + datetime.timedelta(weeks=1):
+                # 表明本周后边还有交易日，今天不需要更新
+                print(f'stock factor only update on the last day of week, not today {end_date_dt}')
+                return
+            else:
+                index_info = DataManager.basic_data("get_index_info")
+                if index_info is not None:
+                    universe_list: List[str] = index_info[index_info.is_stock_factor_universe != 0].index_id.to_list()
+                    # 加进去一个default
+                    universe_list.append('default')
+                    print(f'[update_stock_factor] universe list: {universe_list}')
+
+                    failed_factors: List[str] = StockFactorUpdater.do_update_everyday(yesterday, universe_list)
+                else:
+                    failed_factors: List[str] = ['index_info']
+
+        if wechat_bot is None:
+            from .util.wechat_bot import WechatBot
+            wechat_bot = WechatBot()
+        wechat_bot.send_update_stock_factor_result(yesterday, failed_factors)
+
 
 if __name__ == "__main__":
     entrance = SurfingEntrance()
