@@ -74,6 +74,18 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {SectorFunds.__tablename__}')
 
+    def get_sector_index_info(self):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        SectorFunds
+                )
+                ret_df = pd.read_sql(query.statement, query.session.bind)
+                return ret_df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {SectorFunds.__tablename__}')
+
     def get_sector_main_index_id(self, sector_id):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -416,6 +428,19 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundSize.__tablename__}')
 
+    def get_fund_open_info(self):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        FundOpenInfo,
+                    )
+                tag_df = pd.read_sql(query.statement, query.session.bind)
+                return tag_df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundOpenInfo.__tablename__}')
+
+
     def get_fund_status(self):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -426,6 +451,16 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundStatusLatest.__tablename__}')
 
+    def get_fund_conv_stats(self):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        FundConvStats,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e}')
+
     @staticmethod
     def get_history_fund_size(fund_id: str = '', start_date=None, end_date=None):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -492,6 +527,60 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {Fund_size_and_hold_rate.__tablename__}')
                 return pd.DataFrame([])
 
+    @staticmethod
+    def get_fund_company_hold(start_date='', end_date='', fund_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    Fund_size_and_hold_rate.fund_id,
+                    Fund_size_and_hold_rate.datetime,
+                    Fund_size_and_hold_rate.institution_holds,
+                )
+                if fund_list:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.fund_id.in_(fund_list),
+                    )
+                if start_date:
+                    query = query.filter(
+                        # 按报告日多选取3个月，保证初值可以fill出来
+                        Fund_size_and_hold_rate.datetime >= (pd.to_datetime(start_date) - datetime.timedelta(days=100)).strftime('%Y%m%d'),
+                    )
+                if end_date:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {Fund_size_and_hold_rate.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_fund_persional_hold(start_date='', end_date='', fund_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    Fund_size_and_hold_rate.fund_id,
+                    Fund_size_and_hold_rate.datetime,
+                    Fund_size_and_hold_rate.personal_holds,
+                )
+                if fund_list:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.fund_id.in_(fund_list),
+                    )
+                if start_date:
+                    query = query.filter(
+                        # 按报告日多选取3个月，保证初值可以fill出来
+                        Fund_size_and_hold_rate.datetime >= (pd.to_datetime(start_date) - datetime.timedelta(days=100)).strftime('%Y%m%d'),
+                    )
+                if end_date:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {Fund_size_and_hold_rate.__tablename__}')
+                return pd.DataFrame([])
+
     @staticmethod
     def get_fund_size_all_data():
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -750,6 +839,17 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldBond.__tablename__}')
                 return
 
+    def get_fund_ipo_stats(self, dt: str = '') -> pd.DataFrame:
+       with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundIPOStats
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundIPOStats.__tablename__}')
+                return
+
     def delete_fund_hold_bond(self, date_to_delete: datetime.date, fund_list: List[str]):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -765,6 +865,21 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to delete data <err_msg> {e} from {FundHoldBond.__tablename__}')
                 return False
 
+    def get_fund_stock_portfolio(self, dt: str = ''):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundStockPortfolio
+                )
+                if dt:
+                    query = query.filter(
+                        FundStockPortfolio.datetime == dt
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundStockPortfolio.__tablename__}')
+                return
+
     def delete_fund_rate(self, date_to_delete: datetime.date, fund_list: List[str]):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
