@@ -503,6 +503,26 @@ class DerivedDataApi(metaclass=Singleton):
                 )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print(f'Failed to get_stock_factor_info {e} from {ThirdPartyPortfolioPositionLatest.__tablename__}')
+                print(f'Failed to get_stock_factor_info {e} from {StockFactorInfo.__tablename__}')
                 return
 
+    def get_fund_industry_exposure(self, fund_id):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                sub_q = session.query(
+                    FundIndicatorGroup.datetime.label('latest_time'),
+                ).order_by(
+                    FundIndicatorGroup.datetime.desc(),
+                ).limit(1).subquery()
+
+                query = session.query(
+                    FundIndustryExposure
+                ).filter(
+                    FundIndustryExposure.fund_id == fund_id,
+                    FundIndustryExposure.datetime == sub_q.c.latest_time,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_fund_industry_exposure {e} from {FundIndicatorGroup.__tablename__}')
+                return pd.DataFrame([])
+
