@@ -590,6 +590,21 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {EmStockFinFac.__tablename__}')
                 return None
 
+    def delete_em_stock_fin_fac(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    EmStockFinFac
+                ).filter(
+                    EmStockFinFac.CODES.in_(fund_list),
+                    EmStockFinFac.DATES == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {EmStockFinFac.__tablename__}')
+                return False
+
     def get_em_stock_estimate_fac(self, predict_year: int, start_date: str = '', end_date: str = ''):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
@@ -1175,6 +1190,22 @@ class RawDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmFundIPOStats.__tablename__}')
 
+    def get_em_fund_stock_portfolio(self, start_date: str = '', end_date: str = ''):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmFundStockPortfolio)
+                if start_date:
+                    query = query.filter(
+                        EmFundStockPortfolio.report_date >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmFundStockPortfolio.report_date <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmFundStockPortfolio.__tablename__}')
+
     def get_em_stock_industrial_capital(self):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
@@ -1197,30 +1228,70 @@ class RawDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to delete data <err_msg> {e} from {EmStockIndustrialCapital.__tablename__}')
 
-    def get_em_stock_industrial_capital_trade_detail(self):
+    def get_em_stock_industrial_capital_trade_detail(self, start_date: str = '', end_date: str = ''):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EmStockIndustrialCapitalTradeDetail)
+                if start_date:
+                    query = query.filter(
+                        EmStockIndustrialCapitalTradeDetail.notice_date >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmStockIndustrialCapitalTradeDetail.notice_date <= end_date,
+                    )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmStockIndustrialCapitalTradeDetail.__tablename__}')
 
-    def get_em_stock_shsz_to_hk_connect(self):
+    def get_em_stock_shsz_to_hk_connect(self, start_date: str = '', end_date: str = ''):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EmSHSZToHKStockConnect)
+                if start_date:
+                    query = query.filter(
+                        EmSHSZToHKStockConnect.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmSHSZToHKStockConnect.datetime <= end_date,
+                    )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmSHSZToHKStockConnect.__tablename__}')
 
-    def get_em_stock_research_info(self):
+    def get_em_stock_research_info(self, start_date: str = '', end_date: str = ''):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EmStockResearchInfo)
+                if start_date:
+                    query = query.filter(
+                        EmStockResearchInfo.DATES >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmStockResearchInfo.DATES <= end_date,
+                    )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmStockResearchInfo.__tablename__}')
 
+    def get_em_stock_refinancing(self, start_date: str = '', end_date: str = ''):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmStockRefinancing)
+                if start_date:
+                    query = query.filter(
+                        EmStockRefinancing.APPROVENOTICEDATE >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmStockRefinancing.APPROVENOTICEDATE <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmStockRefinancing.__tablename__}')
+
     def get_em_stock_yearly(self, columns: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
@@ -1236,3 +1307,15 @@ class RawDataApi(metaclass=Singleton):
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmStockYearly.__tablename__}')
+
+    def get_em_industry_info(self):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmIndustryInfo,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_industry_info <err_msg> {e} from {EmIndustryInfo.__tablename__}')
+                return pd.DataFrame([])
+
