@@ -529,14 +529,14 @@ class BasicDataPart1:
         try:
             df = pd.read_csv('./data/sector_info.csv', index_col=0)
             df['sector_type'] = df['sector_type'].map({'industry': SectorType.industry.name, 'topic': SectorType.topic.name})
-            self._data_helper._upload_basic(df, SectorInfo.__table__.name, to_truncate=True)
+            self._data_helper._upload_basic(df, SectorInfo.__table__.name, to_truncate=True) 
             return True
         except Exception as e:
             print(e)
             traceback.print_exc()
             return False
 
-    def sector_funds(self):
+    def sector_funds(self, dm):
         def _lambda_sector_funds_1(em_id_map: Dict[str, str], x: str):
             try:
                 return em_id_map[x]
@@ -552,6 +552,19 @@ class BasicDataPart1:
             df = pd.read_csv('./data/sector_funds.csv', index_col=0)
             df['csi_index_id'] = df['csi_index_id'].transform(lambda x: _lambda_sector_funds_1({em_id.split('.')[0]: em_id for em_id in em_id_list if em_id is not None}, x))
             df['index_id'] = df['csi_index_id'].map(em_id_to_index_id)
+            sector_funds = BasicDataApi().get_sector_index_info()
+            fund_score = dm.dts.fund_indicator_score
+            sector_funds = sector_funds.dropna(subset=['fund_id'])
+            sector_list = df.sector_id.tolist()
+            sector_dic = {}
+            for sector_id in sector_list:
+                fund_list = sector_funds[sector_funds.sector_id == sector_id].fund_id.tolist()
+                top_fund = fund_score.loc[fund_score.index.intersection(fund_list)].sort_values('total_score', ascending=False)#
+                if top_fund.empty:
+                    continue
+                top_fund = top_fund.index[0]
+                sector_dic[sector_id] = top_fund
+            df.loc[:,'main_fund_id'] = df.sector_id.map(lambda x : sector_dic.get(x, None))
             self._data_helper._upload_basic(df, SectorFunds.__table__.name, to_truncate=True)
             return True
         except Exception as e:
@@ -758,12 +771,13 @@ class BasicDataPart1:
                 real_date = RawDataHelper.get_prev_target_date(end_date, QUARTER_UPDATE_DATE_LIST)
                 df = self._raw_data_api.get_em_fund_hold_asset(real_date, real_date)
             df['CODES'] = df.apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
-            df = df.drop(columns='_update_time').dropna(subset=['CODES']).drop_duplicates(subset='CODES')
+            df = df.drop(columns='_update_time').dropna(subset=['CODES']).drop_duplicates(subset=['CODES', 'DATES'], keep='last')
             name_dict = {
                 'CODES': 'fund_id',
                 'DATES': 'datetime',
                 'PRTSTOCKTONAV': 'stock_nav_ratio',
                 'PRTBONDTONAV': 'bond_nav_ratio',
+                'PRTFUNDTONAV': 'fund_nav_ratio',
                 'PRTCASHTONAV': 'cash_nav_ratio',
                 'PRTOTHERTONAV': 'other_nav_ratio',
                 'MMFFIRSTREPOTONAV': 'first_repo_to_nav',
@@ -886,6 +900,39 @@ class BasicDataPart1:
             traceback.print_exc()
             return False
 
+    def fund_stock_portfolio(self, start_date: str, end_date: str, is_history=True):
+        try:
+            if is_history:
+                # history, update only on report date
+                df = self._raw_data_api.get_em_fund_stock_portfolio(start_date, end_date)
+            else:
+                real_date = RawDataHelper.get_prev_target_date(end_date, SEMI_UPDATE_DATE_LIST)
+                df = self._raw_data_api.get_em_fund_stock_portfolio(real_date, real_date)
+            df = df.drop(columns='_update_time')
+            df['em_id'] = df.apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.em_id.split('.')[0], x.report_date), axis=1)
+            df = df[df.em_id.notna()]
+            name_dict = {
+                'em_id': 'fund_id',
+                'report_date': 'datetime',
+            }
+            df = df.rename(columns=name_dict)
+            # if not is_history:
+            #     now_df = BasicDataApi().get_fund_stock_portfolio(dt=real_date)
+            #     if now_df is not None:
+            #         # 过滤出来新增基金benchmark以及旧基金的benchmark发生变化的情况
+            #         now_df = now_df.drop(columns=['_update_time']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset='fund_id', keep='last')
+            #         # merge on all columns
+            #         df = df.merge(now_df, how='left', indicator=True, validate='one_to_one')
+            #         df = df[df._merge == 'left_only'].drop(columns=['_merge'])
+            #     # TODO: 最好原子提交下边两步
+            #     BasicDataApi().delete_fund_hold_bond(real_date, df.fund_id.to_list())
+            # self._data_helper._upload_basic(df, FundStockPortfolio.__table__.name)
+            return True
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return False
+
     def mng_info(self):
         df = self._raw_data_api.get_em_mng_info()
         df['fund_id'] = df.apply(lambda x : 
@@ -919,6 +966,24 @@ class BasicDataPart1:
         df = df.drop(['em_id','_update_time'],axis=1)
         self._data_helper._upload_basic(df, FundOpenInfo.__table__.name)
 
+    def stock_in_fund(self):
+        dt = datetime.date(2020,9,30)
+        stock_info = RawDataApi().get_em_stock_info()
+        fund_info = BasicDataApi().get_fund_info()
+        stock_fund = BasicDataApi().get_fund_hold_stock(dt=dt)
+        stock_fund = stock_fund.set_index('fund_id')
+        cols = [[f'rank{i+1}_stock_code', f'rank{i+1}_stock', f'rank{i+1}_stockweight'] for i in range(10)]
+        res = []
+        for i in cols:
+            df = stock_fund[i]
+            df.columns = ['stock_id','stock_name','stock_weight']
+            res.append(df)
+        stock_fund = pd.concat(res).dropna(axis=0)
+        stock_fund = stock_fund.reset_index()
+        stock_fund['datetime'] = dt
+        stock_fund = pd.merge(stock_fund, fund_info[['fund_id','desc_name']].rename(columns={'desc_name':'fund_name'}), on ='fund_id')
+        self._data_helper._upload_basic(stock_fund, FundOpenInfo.__table__.name)
+
     def process_all(self, start_date, end_date):
         failed_tasks = []
         # Depend on RQ
