@@ -193,7 +193,7 @@ class FundScoreManager:
                 'active': ScoreFunc(mng_trade_year=0.15, mng_annualized_ret=0.15, mng_sharpe=0.15,alpha=0.1,mng_model_alpha=0.3,mng_model_beta=0.15,active=10),  
             },
             'national_debt': {
-                'default':ScoreFunc(alpha=0.20, beta=-0.45, track_err=-0.35),
+                'default':ScoreFunc(alpha=0.20, beta=-0.45, track_err=-0.35),#, fee_rate=-0.2),
             }, 
             'mmf':{
                 'default':ScoreFunc(alpha=0.3, beta=-0.2, fee_rate=-0.1, track_err=-0.4),
