@@ -25,7 +25,7 @@ class SectorInfo(Base):
     sector_desc = Column(TEXT, nullable=False)  # 板块描述
     sector_name = Column(CHAR(16), nullable=False, unique=True)  # 板块名称
     main_index_id = Column(CHAR(16), nullable=False)  # 板块代表指数
-
+    main_fund_id = Column(CHAR(16))  # 板块代表基金
 
 class SectorFunds(Base):
     '''板块基金表'''
@@ -398,6 +398,7 @@ class FundHoldAsset(Base):
     datetime = Column(DATE, primary_key=True)  # 日期
     stock_nav_ratio = Column(DOUBLE(asdecimal=False)) # 股票市值占基金资产净值比
     bond_nav_ratio = Column(DOUBLE(asdecimal=False)) # 债券市值占基金资产净值比
+    fund_nav_ratio = Column(DOUBLE(asdecimal=False)) # 基金市值占基金资产净值比
     cash_nav_ratio = Column(DOUBLE(asdecimal=False)) # 银行存款占基金资产净值比
     other_nav_ratio = Column(DOUBLE(asdecimal=False)) # 其他资产占基金资产净值比
     first_repo_to_nav = Column(DOUBLE(asdecimal=False))  # 报告期内债券回购融资余额占基金资产净值比例
@@ -516,6 +517,20 @@ class FundHoldBond(Base):
     rank10_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank10_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
 
+class FundStockPortfolio(Base):
+    '''基金的股票全部持仓'''
+
+    __tablename__ = 'fund_stock_portfolio'
+
+    fund_id = Column(CHAR(10), primary_key=True)  # 基金代码
+    datetime = Column(DATE, primary_key=True)  # 报告期
+    stock_id = Column(CHAR(10), primary_key=True)  # 股票代码
+    hold_number = Column(DOUBLE(asdecimal=True), nullable=False)  # 持股数量(万股)
+    semi_change = Column(DOUBLE(asdecimal=True))  # 半年度持股变动(万股)
+    stock_mv = Column(DOUBLE(asdecimal=True))  # 持股市值(万元)
+    net_asset_ratio = Column(DOUBLE(asdecimal=True))  # 占净值比(%)
+    mv_ratio = Column(DOUBLE(asdecimal=True))  # 占股票投资市值比(%)
+
 class MngInfo(Base):
     '''基金经理信息表'''
 
@@ -638,4 +653,18 @@ class FundOpenInfo(Base):
     __tablename__ = 'fund_open_info'
 
     fund_id = Column(CHAR(10), primary_key=True) # 代码
-    desc_name = Column(CHAR(64)) # 基金名称
\ No newline at end of file
+    desc_name = Column(CHAR(64)) # 基金名称
+
+class StockInFund(Base):
+    '''基金重仓股'''
+
+    __tablename__ = 'stock_in_fund'
+
+    fund_id = Column(CHAR(10), primary_key=True)  # 基金代码
+    stock_id = Column(CHAR(10), primary_key=True) # 股票代码
+    datetime = Column(DATE, primary_key=True) # 日期
+    stock_name = Column(CHAR(64)) # 股票名称
+    stock_weight = Column(DOUBLE(asdecimal=False)) # 股票在基金权重
+    fund_name = Column(CHAR(64)) # 基金名称
+
+    
\ No newline at end of file
