@@ -2,7 +2,7 @@ from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATE, DATETIME, SMALLINT
 
-from ...constant import StockFactorType
+from ...constant import StockFactorType, IndClassType
 
 
 class Base():
@@ -499,7 +499,7 @@ class FundManagerInfo(Base):
     nationality = Column(CHAR(10)) # 国籍
     resume = Column(TEXT) # 简历
     end_date = Column(DATE) # 基金经理离职时间
-
+    company_id = Column(CHAR(64)) # 基金公司
 
 class FundManagerFundRank(Base):
     '''基金经理基金排名'''
@@ -672,3 +672,13 @@ class StockFactorInfo(Base):
     f_name = Column(TEXT, nullable=False)  # 因子名称
     is_selected_by_default = Column(BOOLEAN, nullable=False)  # 是否默认被选中
     f_desc = Column(TEXT)  # 因子简介
+
+class FundIndustryExposure(Base):
+    '''基金行业暴露'''
+
+    __tablename__ = 'fund_industry_exposure'
+
+    fund_id = Column(CHAR(10), primary_key=True) # 基金ID
+    datetime = Column(DATE, primary_key=True) # 日期
+    ind_class_type = Column(Enum(IndClassType), nullable=False)  # 行业分类类型
+    value = Column(TEXT, nullable=False)  # JSON格式的行业暴露数据
