@@ -3,7 +3,7 @@ from sqlalchemy import CHAR, Column, Integer, TEXT, BOOLEAN, text, Index, Enum
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, DATETIME, MEDIUMTEXT, YEAR, SMALLINT
 
-from ...constant import SectorType, IndexPriceSource, CodeFeeMode
+from ...constant import SectorType, IndexPriceSource, CodeFeeMode, IndClassType
 
 
 class Base():
@@ -607,7 +607,7 @@ class EmStockInfo(Base):
     CITICCODE2020 = Column("citic_code_2020", CHAR(40)) # 所属中信行业代码(2020)
     BLCSRCINDCODE = Column("bl_csrc_ind_code", CHAR(32)) # 所属证监会行业指数代码
     CSRCCODENEW = Column("csrc_code_new", CHAR(16)) # 所属证监会行业(新)代码
-    CSINDCODE2016 = Column("cs_ind_code_2016", CHAR(32), nullable=False) # 所属中证行业(2016)代码
+    CSINDCODE2016 = Column("cs_ind_code_2016", CHAR(32)) # 所属中证行业(2016)代码
     GICSCODE = Column("gics_code", CHAR(32), nullable=False) # 所属GICS行业代码
 
 
@@ -1041,10 +1041,11 @@ class EMFundHoldAsset(Base):
 
     CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
     DATES = Column(DATE, primary_key=True) # 日期
-    PRTSTOCKTONAV = Column(DOUBLE(asdecimal=False))#股票市值占基金资产净值比
-    PRTBONDTONAV = Column(DOUBLE(asdecimal=False))#债券市值占基金资产净值比
-    PRTCASHTONAV = Column(DOUBLE(asdecimal=False))#银行存款占基金资产净值比
-    PRTOTHERTONAV = Column(DOUBLE(asdecimal=False))#其他资产占基金资产净值比
+    PRTSTOCKTONAV = Column(DOUBLE(asdecimal=False)) # 股票市值占基金资产净值比
+    PRTBONDTONAV = Column(DOUBLE(asdecimal=False)) # 债券市值占基金资产净值比
+    PRTFUNDTONAV = Column(DOUBLE(asdecimal=False)) # 基金市值占基金资产净值比
+    PRTCASHTONAV = Column(DOUBLE(asdecimal=False)) # 银行存款占基金资产净值比
+    PRTOTHERTONAV = Column(DOUBLE(asdecimal=False)) # 其他资产占基金资产净值比
     MMFFIRSTREPOTONAV = Column(DOUBLE(asdecimal=False))  # 报告期内债券回购融资余额占基金资产净值比例
     MMFAVGPTM = Column(DOUBLE(asdecimal=False))  # 报告期末投资组合平均剩余期限
 
@@ -1420,6 +1421,21 @@ class EmFundOpen(Base):
     desc_name = Column(CHAR(20)) # 名称
 
 
+class EmFundStockPortfolio(Base):
+    '''Choice基金的股票全部持仓'''
+
+    __tablename__ = 'em_fund_stock_portfolio'
+
+    em_id = Column(CHAR(10), primary_key=True)  # 基金代码
+    report_date = Column(DATE, primary_key=True)  # 报告期
+    stock_id = Column(CHAR(10), primary_key=True)  # 股票代码
+    hold_number = Column(DOUBLE(asdecimal=True), nullable=False)  # 持股数量(万股)
+    semi_change = Column(DOUBLE(asdecimal=True))  # 半年度持股变动(万股)
+    stock_mv = Column(DOUBLE(asdecimal=True))  # 持股市值(万元)
+    net_asset_ratio = Column(DOUBLE(asdecimal=True))  # 占净值比(%)
+    mv_ratio = Column(DOUBLE(asdecimal=True))  # 占股票投资市值比(%)
+
+
 class EmStockIndustrialCapital(Base):
     '''Choice产业资本流动数据'''
 
@@ -1506,6 +1522,16 @@ class EmStockYearly(Base):
     DIVANNUACCUM = Column('div_annu_accum', DOUBLE(asdecimal=False))  # 年度累计分红
 
 
+class EmIndustryInfo(Base):
+    '''Choice行业信息表'''
+
+    __tablename__ = 'em_industry_info'
+
+    em_id = Column(CHAR(16), primary_key=True)  # EM ID
+    ind_name = Column(TEXT, nullable=False)  # 行业名称
+    ind_class_type = Column(Enum(IndClassType), nullable=False)  # 行业分类类型
+
+
 class SuntimeReportEarningsAdjust(Base):
     '''朝阳永续报告盈利预测调整表'''
 
