@@ -1,6 +1,6 @@
-from sqlalchemy import CHAR, Column, DATE, text, TEXT, Integer
+from sqlalchemy import CHAR, Column, DATE, text, TEXT, Integer, BOOLEAN
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.dialects.mysql import DOUBLE, DATETIME
+from sqlalchemy.dialects.mysql import DOUBLE, DATETIME, TINYINT
 
 
 class Base():
@@ -324,6 +324,8 @@ class IndexDailyCollection(Base):
     tag_method = Column(CHAR(64))  # 估值评分采用方法
     desc_name = Column(CHAR(64))  # 名称
     id_cat = Column(CHAR(64), nullable=False)  # 所属类型
+    is_select = Column(BOOLEAN, nullable=False)  # 是否属于精选
+    val_level = Column(CHAR(10))  # 指数估值水平
 
     @staticmethod
     def trans_columns():
@@ -389,6 +391,8 @@ class IndexDailyCollection(Base):
             'tag_method': '估值评分采用方法',
             'desc_name': '指数名称',
             'id_cat': '所属类型',
+            'is_select': '精选指数',
+            'val_level': '估值水平',
         }
 
 
@@ -471,3 +475,72 @@ class AutomaticInvestmentCollection(Base):
             'intel_y5_ret': '智能定投五年收益',
         }
 
+
+class FundRecommendationCollection(Base):
+    """基金推荐月度收集"""
+
+    __tablename__ = 'fund_recommendation_collection'
+
+    fund_id = Column(CHAR(10), primary_key=True) # 基金ID
+    order_book_id = Column(CHAR(10)) # 基金代码
+    desc_name = Column(CHAR(64)) # 基金名称
+    company_id = Column(CHAR(64)) # 基金公司
+    wind_class_1 = Column(CHAR(64)) # Wind基金类型
+    wind_class_2 = Column(CHAR(64)) # Wind基金二级类型
+    risk_level = Column(CHAR(2))  # 风险等级
+    is_ipo_fund = Column(TINYINT(1)) # 是否是打新基金
+    sector_list = Column(TEXT) # 板块列表 需要json.loads
+    sector_name = Column(TEXT) # 板块名字列表 需要json.loads
+    index_list = Column(TEXT) # 指数列表 需要json.loads
+    index_name = Column(TEXT) # 指数名字列表 需要json.loads
+    mdd = Column(DOUBLE(asdecimal=False)) # 最大回撤
+    annual_ret = Column(DOUBLE(asdecimal=False)) # 年化收益
+    ret_ability = Column(DOUBLE(asdecimal=False)) # 收益能力
+    risk_ability = Column(DOUBLE(asdecimal=False)) # 风险能力
+    stable_ability = Column(DOUBLE(asdecimal=False)) # 稳定能力
+    select_time = Column(DOUBLE(asdecimal=False)) # 择时能力
+    select_stock = Column(DOUBLE(asdecimal=False)) # 择股能力
+    mng_score = Column(DOUBLE(asdecimal=False)) # 团队能力
+    total_score = Column(DOUBLE(asdecimal=False)) # 总分
+    mng_id = Column(CHAR(64)) # 基金经理id
+    mng_name = Column(CHAR(64)) # 基金经理名字
+    fund_type = Column(CHAR(64)) # 基金大类类型
+
+    @staticmethod
+    def trans_columns():
+        return {
+            'fund_id': '基金ID',
+            'order_book_id': '基金代码',
+            'desc_name': '基金名称',
+            'company_id': '基金公司名字',
+            'wind_class_1': '基金类型一',
+            'wind_class_2': '基金类型二',
+            'risk_level': '基金风险等级',
+            'is_ipo_fund': '是否是打新基金',
+            'sector_list': '板块列表',
+            'sector_name': '板块名字列表',
+            'index_list': '指数列表',
+            'index_name': '指数名字列表',
+            'mdd': '最大回撤',
+            'annual_ret': '年化收益',
+            'ret_ability': '基金收益能力',
+            'risk_ability': '基金风险能力',
+            'stable_ability': '基金稳定能力',
+            'select_time': '基金择时能力',
+            'select_stock': '基金择股能力',
+            'mng_score': '基金团队能力',
+            'total_score': '基金总分',
+            'mng_id': '基金经理id',
+            'mng_name': '基金经理名字',
+            'fund_type': '基金大类类型',
+        }
+
+class ManagerInfoCollection(Base):
+    """基金经理评价"""
+
+    __tablename__ = 'manager_info_collection'
+
+    mng_id = Column(CHAR(10), primary_key=True) # 经理ID
+    mng_name = Column(CHAR(30)) # 经理名
+    introduction = Column(TEXT) # 介绍
+    fund_type = Column(CHAR(64)) # 基金大类类型
\ No newline at end of file
