@@ -480,7 +480,8 @@ class FundPainter(object):
     def plot_rolling_analysis( annual_ret:pd.DataFrame, 
                                fund_annual_ret:float,
                                year:int,
-                               index_id:'str'):
+                               index_id:'str',
+                               ret_list:list):
         
         df1 = annual_ret.dropna()[[index_id,'战略配置']]
         index = df1.index
@@ -558,11 +559,23 @@ class FundPainter(object):
         cdf_loc = df_funds.loc[index_loc, 'cdf']
         df_funds = 1 - df_funds[['cdf']]
         df_funds[['cdf']].plot.line(figsize=(12,6), legend=None)
+        _st_low = ''
+        _st_high = ''
         mean_ret = round(100 * abs(df_funds['cdf'] - 0.5).idxmin(),2)
+        for ret_i in ret_list:
+            if ret_i < mean_ret/100:
+                prob = round(1 - df_funds[['cdf']].loc[:ret_i].cdf.values[-1],3)
+                _ret_s = f'ret {ret_i} prob {prob}  '
+                _st_low += _ret_s
+            else:
+                prob = round(df_funds[['cdf']].loc[:ret_i].cdf.values[-1],3)
+                _ret_s = f'ret {ret_i} prob {prob}  '
+                _st_high += _ret_s
         plt.scatter(index_loc, 1-cdf_loc, marker='D', color='C1', s=60)
         plt.title(f'{year}年年化收益 累积密度分布', fontsize=20)
         rate = round((1-cdf_loc)*100,2)
         st = f'组合年化收益 {round(fund_annual_ret * 100, 2)}%  获取年化收益胜率 {rate}%  50%胜率年化收益 {mean_ret}%'
+        st = st + '\n 低于收益概率' + _st_low + '\n 高于收益概率' + _st_high
         plt.suptitle(st,y=0.87,fontsize=17)
         plt.grid()
         plt.show()
