@@ -1,5 +1,5 @@
 
-from typing import Optional
+from typing import Optional, Set
 # from functools import lru_cache
 import pandas as pd
 
@@ -16,9 +16,10 @@ class Factor(metaclass=Singleton):
         self._f_name: str = f_name
         self._s3_file_name: str = f'{f_name}.parquet'
         self._f_type: StockFactorType = f_type
-        self._s3_uri: str = f's3://{_BUCKET_NAME}/factor/' + self._s3_file_name
+        self._s3_uri: str = f's3://{_BUCKET_NAME}/factor/'
         self._s3_uri_factor_ret: str = f's3://{_BUCKET_NAME}/factor_ret/'
         self._factor: Optional[pd.DataFrame] = None
+        self._deps: Set[Factor] = set()
 
     # @lru_cache
     def get(self, universe: str = 'default') -> Optional[pd.DataFrame]:
@@ -48,8 +49,7 @@ class Factor(metaclass=Singleton):
     def save(self) -> bool:
         if self._factor is None:
             return False
-        self._factor.to_parquet(self._s3_uri, compression='gzip')
-        # TODO: 存储factor_return
+        self._factor.to_parquet(self._get_s3_factor_uri, compression='gzip')
         return True
 
     def calc(self):
@@ -57,11 +57,18 @@ class Factor(metaclass=Singleton):
 
     def _load_data(self) -> Optional[pd.DataFrame]:
         try:
-            self._factor: pd.DataFrame = pd.read_parquet(self._s3_uri)
+            self._factor: pd.DataFrame = pd.read_parquet(self._get_s3_factor_uri)
         except Exception as e:
             print(f'retrieve data from s3 failed, (err_msg){e}; try to re-calc')
             self.calc()
         return self._factor
 
+    @property
+    def _get_s3_factor_uri(self) -> str:
+        return f'{self._s3_uri}{self._s3_file_name}'
+
+    def _get_s3_factor_uri_with_universe(self, universe: str) -> str:
+        return f'{self._s3_uri}with_universe/{universe}/{self._s3_file_name}'
+
     def _get_s3_factor_ret_uri(self, universe: str) -> str:
         return f'{self._s3_uri_factor_ret}{universe}/{self._s3_file_name}'
