@@ -14,7 +14,6 @@ from .base import Factor
 
 _UTILS_PREFIX = 'utils/'
 _START_DATE = '2005-01-01'
-_END_DATE = '2020-10-27'
 _TRADING_DAYS_PER_YEAR = 242
 
 
@@ -88,10 +87,15 @@ class TradingDayList(Factor):
         super().__init__(_UTILS_PREFIX + 'td_list', StockFactorType.BASIC)
 
     def calc(self):
-        trading_day_list: Optional[pd.DataFrame] = DataManager.basic_data('get_trading_day_list', start_date=_START_DATE, end_date=_END_DATE)
+        trading_day_list: Optional[pd.DataFrame] = DataManager.basic_data('get_trading_day_list', start_date=_START_DATE)
 
         self._factor = trading_day_list.datetime
 
+    def trim_by_date(self, end_date: str):
+        if self._factor is None:
+            return
+        self._factor = self._factor[self._factor <= pd.to_datetime(end_date).date()]
+
 
 class FundHoldStockFactor(Factor):
 
@@ -100,3 +104,13 @@ class FundHoldStockFactor(Factor):
 
     def calc(self):
         self._factor = DataManager.basic_data('get_fund_hold_stock_by_id').drop(columns='_update_time')
+
+
+class StockIndustryInfoFactor(Factor):
+
+    def __init__(self):
+        super().__init__(_UTILS_PREFIX + 'stock_ind_info', StockFactorType.BASIC)
+
+    def calc(self):
+        df: Optional[pd.DataFrame] = DataManager.raw_data('get_em_stock_info').drop(columns='_update_time')
+        self._factor = df.set_index('stock_id').bl_sws_ind_code.str.split(pat='-', expand=True).iloc[:, -1]
