@@ -67,3 +67,11 @@ class WechatBot(object):
         else:
             markdown_content += f'\n><font color=\"info\">同步所有table成功</font>'
         self.send(markdown_content)
+
+    def send_update_stock_factor_result(self, dt, failed_factors: List[str]):
+        markdown_content = f'#### {dt}'
+        if failed_factors:
+            markdown_content += f'\n>**更新下列factor失败: <font color=\"warning\">{failed_factors}</font>**'
+        else:
+            markdown_content += f'\n><font color=\"info\">更新所有factor成功</font>'
+        self.send(markdown_content)
